@@ -1,4 +1,4 @@
-%% Copyright (C) 2018 Colin B. Macdonald
+%% Copyright (C) 2018-2019, 2022 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -46,28 +46,26 @@ function y = pochhammer (n, x)
     error ('pochhammer: inputs N and X must have compatible sizes')
   end
 
-  % TODO: Sympy's RisingFactorial doesn't work so we call mpmath here
-  % https://github.com/sympy/sympy/issues/14822
   cmd = { 'Ln = _ins[0]'
           'Lx = _ins[1]'
           'if len(Ln) == 1 and len(Lx) != 1:'
           '    Ln = Ln*len(Lx)'
           'if len(Ln) != 1 and len(Lx) == 1:'
           '    Lx = Lx*len(Ln)'
-          'import mpmath'
-          'c = [complex(mpmath.rf(complex(n), complex(x))) for n,x in zip(Ln, Lx)]'
+          'c = [complex(mpmath.rf(n, x)) for n,x in zip(Ln, Lx)]'
           'return c,' };
-  c = python_cmd (cmd, num2cell (n(:)), num2cell (x(:)));
+  c = pycall_sympy__ (cmd, num2cell (n(:)), num2cell (x(:)));
   for i = 1:numel (c)
     y(i) = c{i};
   end
 end
 
 
+%!error pochhammer (1)
+%!error pochhammer (1, 2, 3)
+
 %!error <sizes> pochhammer ([1 2], [1 2 3])
 %!error <sizes> pochhammer ([1 2], [1; 2])
-%!error <Invalid> pochhammer (1, 2, 3)
-%!error <Invalid> pochhammer (1)
 
 %!test
 %! y = sym(11)/10;
@@ -96,8 +94,7 @@ end
 %! B = pochhammer ([0.9 0.8], [3.1 4.2]);
 %! assert (A, B, -3*eps);
 
-%!xtest
-%! % broken upstream, https://github.com/sympy/sympy/issues/14822
+%!test
 %! % x matrix, s scalar
 %! y = [1 2 sym(pi); exp(sym(1)) 5 6];
 %! t = sym(2);
@@ -105,7 +102,7 @@ end
 %! s = 2;
 %! A = pochhammer (s, x);
 %! B = double (pochhammer (t, y));
-%! assert (A, B, -eps);
+%! assert (A, B, -3*eps);
 
 %!test
 %! % s matrix, x scalar
