@@ -1,4 +1,4 @@
-%% Copyright (C) 2016-2018 Colin B. Macdonald
+%% Copyright (C) 2016-2019, 2022 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -32,7 +32,7 @@
 %%
 %% @strong{Note} this function may be slow for large numbers of inputs.
 %% This is because it is not a native double-precision implementation
-%% but rather the numerical evaluation of the SymPy function
+%% but rather the numerical evaluation of the Python @code{mpmath} function
 %% @code{zeta}.
 %%
 %% TODO: The two-argument form is not yet implemented.
@@ -49,9 +49,9 @@ function y = zeta (n, x)
   if (nargin == 1)
     x = n;
     cmd = { 'L = _ins[0]'
-            'A = [complex(zeta(complex(x))) for x in L]'
+            'A = [complex(mpmath.zeta(x)) for x in L]'
             'return A,' };
-    c = python_cmd (cmd, num2cell (x(:)));
+    c = pycall_sympy__ (cmd, num2cell (x(:)));
     y = reshape (cell2mat (c), size (x));
     return
   end
@@ -60,7 +60,7 @@ function y = zeta (n, x)
 end
 
 
-%!error <Invalid> zeta (1, 2, 3)
+%!error zeta (1, 2, 3)
 %!assert (isnan (zeta (nan)))
 
 %!test
@@ -90,3 +90,5 @@ end
 %!        175.09070083717643866 - 71.512541417467273425*1i ];
 %! B = zeta (x);
 %! assert (A, B, -eps)
+
+%!assert (zeta (inf), 1.0)
