@@ -1,4 +1,4 @@
-%% Copyright (C) 2015-2016, 2018 Colin B. Macdonald
+%% Copyright (C) 2015-2016, 2018-2019, 2022 Colin B. Macdonald
 %% Copyright (C) 2016 Alex Vong
 %%
 %% This file is part of OctSymPy.
@@ -62,17 +62,15 @@ function c = dot(a, b)
 
   % conjugate a to match the behavior of @double/dot
   cmd = { 'a, b = _ins'
-          'if Version(spver) <= Version("1.3"):'
-          '    return a.conjugate().dot(b)'
           'return a.dot(b, hermitian=True, conjugate_convention="left")'
         };
 
-  c = python_cmd (cmd, sym(a), sym(b));
+  c = pycall_sympy__ (cmd, sym(a), sym(b));
 
 end
 
 
-%!error <Invalid> dot (sym(1), 2, 3)
+%!error dot (sym(1), 2, 3)
 
 %!test
 %! a = sym([1; 1; 0]);
