@@ -1,5 +1,7 @@
-%% Copyright (C) 2014-2016, 2018-2019 Colin B. Macdonald
+%% Copyright (C) 2014-2016, 2018-2019, 2022 Colin B. Macdonald
 %% Copyright (C) 2014-2015 Andrés Prieto
+%% Copyright (C) 2020 Rafael Laboissière
+%% Copyright (C) 2020 Jing-Chen Peng
 %%
 %% This file is part of OctSymPy.
 %%
@@ -21,8 +23,9 @@
 %% @documentencoding UTF-8
 %% @deftypemethod  @@sym {@var{sol} =} dsolve (@var{ode})
 %% @deftypemethodx @@sym {@var{sol} =} dsolve (@var{ode}, @var{IC})
-%% @deftypemethodx @@sym {@var{sol} =} dsolve (@var{ode}, @var{IC1}, @var{IC2}, @dots{})
-%% @deftypemethodx @@sym {[@var{sol}, @var{classify}] =} dsolve (@var{ode}, @var{IC})
+%% @deftypemethodx @@sym {@var{sol} =} dsolve (@var{ODEs}, @var{IC1}, @var{IC2}, @dots{})
+%% @deftypemethodx @@sym {@var{sol} =} dsolve (@var{ODEs}, @var{ICs})
+%% @deftypemethodx @@sym {[@var{sol}, @var{classify}] =} dsolve (@dots{})
 %% Solve ordinary differential equations (ODEs) symbolically.
 %%
 %% Basic example:
@@ -39,8 +42,8 @@
 %% @group
 %% sol = dsolve (DE)
 %%   @result{} sol = (sym)
-%%                  4⋅x
-%%       y(x) = C₁⋅ℯ
+%%           4⋅x
+%%       C₁⋅ℯ
 %% @end group
 %% @end example
 %%
@@ -49,17 +52,6 @@
 %% @group
 %% sol = dsolve (DE, y(0) == 1)
 %%   @result{} sol = (sym)
-%%               4⋅x
-%%       y(x) = ℯ
-%% @end group
-%% @end example
-%%
-%% Note the result is an equation so if you need an expression
-%% for the solution:
-%% @example
-%% @group
-%% rhs (sol)
-%%   @result{} (sym)
 %%        4⋅x
 %%       ℯ
 %% @end group
@@ -77,10 +69,10 @@
 %%
 %% [sol, classify] = dsolve (DE, y(0) == 1)
 %%   @result{} sol = (sym)
-%%                -1
-%%        y(x) = ─────
-%%               x - 1
-%%   @result{} classify = separable
+%%        -1
+%%       ─────
+%%       x - 1
+%%   @result{} classify = ... separable ...
 %% @end group
 %% @end example
 %%
@@ -97,10 +89,10 @@
 %%        dx
 %%
 %% dsolve (DE, y(0) == 1, diff(y)(0) == 12)
-%%   @result{} (sym) y(x) = 4⋅sin(3⋅x) + cos(3⋅x)
+%%   @result{} (sym) 4⋅sin(3⋅x) + cos(3⋅x)
 %%
 %% dsolve (DE, y(0) == 1, y(sym(pi)/2) == 2)
-%%   @result{} (sym) y(x) = -2⋅sin(3⋅x) + cos(3⋅x)
+%%   @result{} (sym) -2⋅sin(3⋅x) + cos(3⋅x)
 %% @end group
 %% @end example
 %%
@@ -123,71 +115,92 @@
 %%
 %% @group
 %% soln = dsolve (ode_sys)
-%%   @result{} soln = @{ ... @}
-%% @end group
+%%   @result{} soln = scalar structure containing ...
+%%        x = ...
+%%        y = ...
 %%
-%% @c doctest: +SKIP  # they might be re-ordered
-%% @group
-%% soln@{1@}
+%% @c doctest: +SKIP_IF(pycall_sympy__ ('return Version(spver) <= Version("1.5.1")'))
+%% soln.x
 %%   @result{} ans =
 %%       (sym)
-%%                      -2⋅t         2⋅t
-%%         x(t) = 2⋅C₁⋅ℯ     + 2⋅C₂⋅ℯ
+%%               -2⋅t       2⋅t
+%%         - C₁⋅ℯ     + C₂⋅ℯ
 %%
-%% @c doctest: +SKIP  # they might be re-ordered
-%% soln@{2@}
+%% @c doctest: +SKIP_IF(pycall_sympy__ ('return Version(spver) <= Version("1.5.1")'))
+%% soln.y
 %%   @result{} ans =
 %%       (sym)
-%%                        -2⋅t         2⋅t
-%%         y(t) = - 2⋅C₁⋅ℯ     + 2⋅C₂⋅ℯ
+%%             -2⋅t       2⋅t
+%%         C₁⋅ℯ     + C₂⋅ℯ
 %% @end group
 %% @end example
 %%
-%% @strong{WARNING}: As of SymPy 0.7.6 (May 2015), there are many problems
-%% with systems, even very simple ones.  Use these at your own risk,
-%% or even better: help us fix SymPy.
-%%
-%% Note: The Symbolic Math Toolbox supports strings like 'Dy + y = 0'; we
+%% Note: The Symbolic Math Toolbox used to support strings like 'Dy + y = 0'; we
 %% are unlikely to support this so you will need to assemble a symbolic
 %% equation instead.
 %%
-%% FIXME: should we support a cell array list input for ICs/BCs?
-%%
 %% @seealso{@@sym/diff, @@sym/int, @@sym/solve}
 %% @end deftypemethod
 
-%% Author: Colin B. Macdonald, Andrés Prieto
-%% Keywords: symbolic
-
 
 function [soln,classify] = dsolve(ode,varargin)
 
   % Usually we cast to sym in the _cmd call, but want to be
   % careful here b/c of symfuns
-  if (any(~isa(ode, 'sym')))
+  if (~ iscell (ode) && ~ all (isa (ode, 'sym')))
     error('Inputs must be sym or symfun')
   end
 
   % FIXME: might be nice to expose SymPy's "sp.ode.classify_sysode" and
   %        "sp.ode.classify_ode" with their own commands
   if (isscalar(ode) && nargout==2)
-    classify = python_cmd ('return sp.ode.classify_ode(_ins[0])[0],', ode);
+    cmd = { 'from sympy.solvers import classify_ode'
+            'return classify_ode(_ins[0]),' };
+    classify = pycall_sympy__ (cmd, ode);
   elseif(~isscalar(ode) && nargout==2)
     warning('Classification of systems of ODEs is currently not supported')
     classify='';
   end
 
   cmd = { 'ode=_ins[0]; ics=_ins[1:]'
-          '# convert our input to a dict'
-          'ics2 = {}'
-          'for s in ics:'
-          '    ics2[s.lhs] = s.rhs'
-          'sol = sp.dsolve(ode, ics=ics2)'
-          'return sol,' };
-  soln = python_cmd (cmd, ode, varargin{:});
+          'if len(ics) == 1:'
+          '    ics = ics[0]'
+          'try:'
+          '    ics = {ic.lhs: ic.rhs for ic in ics}'
+          'except TypeError:'  % not iterable
+          '    ics = {ics.lhs: ics.rhs}'
+          'sol = sp.dsolve(ode, ics=ics)'
+          'def convert_helper(sympy_obj):'
+          '    if isinstance(sympy_obj, Eq) and sympy_obj.lhs.is_Function:'
+                   % y(t) = rhs to str "y", rhs expression
+          '        return str(sympy_obj.lhs.func), sympy_obj.rhs'
+          '    return None, None'
+          % if just single equality with simple lhs, we return the rhs
+          'if isinstance(sol, Eq):'
+          '    if sol.lhs.is_Function:'
+          '        return sol.rhs'
+          % If the solution set is iterable (system or multiple solutions),
+          % we will try to convert to structure of {"x": expr, "y": expr2, ...}
+          'try:'
+          '    return_data = dict()'
+          '    for solution_part in sol:'
+          '        key, rhs = convert_helper(solution_part)'
+          '        if key is None:'
+          '            raise ValueError("not of right form for extraction")'
+          '        if key in return_data.keys():'
+          '            raise KeyError(f"repeated key {key}")'
+          '        return_data[key] = rhs'
+          '    return return_data'
+          'except (TypeError, ValueError, KeyError):'
+          '    pass'
+          % if nothing else worked, give back whatever form we have
+          'return sol' };
+  soln = pycall_sympy__ (cmd, ode, varargin{:});
 end
 
 
+%!error <sym> dsolve (1, sym('x'))
+
 %!test
 %! syms y(x)
 %! de = diff(y, 2) - 4*y == 0;
@@ -195,7 +208,7 @@ end
 %! syms C1 C2
 %! g1 = C1*exp(-2*x) + C2*exp(2*x);
 %! g2 = C2*exp(-2*x) + C1*exp(2*x);
-%! assert (isequal (rhs(f), g1) || isequal (rhs(f), g2))
+%! assert (isequal (f, g1) || isequal (f, g2))
 
 %!test
 %! % Not enough initial conditions
@@ -208,23 +221,36 @@ end
 %! catch
 %!   waserr = true;
 %!   expectederr = regexp (lasterr (), 'Perhaps.*under-specified');
+%!   f = 42;
 %! end
-%! assert ((waserr && expectederr) || isequal (rhs(f), g))
+%! assert ((waserr && expectederr) || isequal (f, g))
 
 %!test
 %! % Solution in implicit form
 %! syms y(x) C1
-%! sol=dsolve((2*x*y(x)-exp(-2*y(x)))*diff(y(x),x)+y(x)==0);
-%! eq=x*exp(2*y(x))-log(y(x))==C1;
-%! assert (isequal (rhs(sol), rhs(eq)) && isequal (lhs(sol), lhs(eq)) )
+%! de = (2*x*y(x) - exp(-2*y(x)))*diff(y(x), x) + y(x) == 0;
+%! sol = dsolve (de);
+%! eqn = x*exp(2*y(x)) - log(y(x)) == C1;
+%! % could differ by signs
+%! sol = lhs (sol) - rhs (sol);
+%! eqn = lhs (eqn) - rhs (eqn);
+%! sol2 = subs (sol, C1, -C1);
+%! assert (isequal (sol, eqn) || isequal (sol2, eqn))
+
+%%!xtest
+%%! % system with solution in implicit form
+%%! % TODO: not implemented upstream?
+%%! syms y(x) z(x) C1
+%%! de1 = (2*x*y(x) - exp(-2*y(x)))*diff(y(x), x) + y(x) == 0;
+%%! de2 = diff(z, x) == 0;
+%%! sol = dsolve ([de1; de2]);
 
 %!test
 %! % Compute solution and classification
 %! syms y(x) C1
-%! [sol,classy]=dsolve((2*x*y(x)-exp(-2*y(x)))*diff(y(x),x)+y(x)==0);
-%! eq=x*exp(2*y(x))-log(y(x))==C1;
-%! assert (isequal (rhs(sol), rhs(eq)) && isequal (lhs(sol), lhs(eq)))
-%! assert (strcmp (classy, '1st_exact'))
+%! de = (2*x*y(x) - exp(-2*y(x)))*diff(y(x), x) + y(x) == 0;
+%! [sol, classy] = dsolve (de);
+%! assert (any (strcmp (classy, '1st_exact')))
 
 %!test
 %! % initial conditions (first order ode)
@@ -232,7 +258,7 @@ end
 %! de = diff(y, x) + 4*y == 0;
 %! f = dsolve(de, y(0) == 3);
 %! g = 3*exp(-4*x);
-%! assert (isequal (rhs(f), g))
+%! assert (isequal (f, g))
 
 %!test
 %! % initial conditions (second order ode)
@@ -240,7 +266,7 @@ end
 %! de = diff(y, 2) + 4*y == 0;
 %! f = dsolve(de, y(0) == 3, subs(diff(y,x),x,0)==0);
 %! g = 3*cos(2*x);
-%! assert (isequal (rhs(f), g))
+%! assert (isequal (f, g))
 
 %!test
 %! % Dirichlet boundary conditions (second order ode)
@@ -248,7 +274,7 @@ end
 %! de = diff(y, 2) + 4*y == 0;
 %! f = dsolve(de, y(0) == 2, y(1) == 0);
 %! g = -2*sin(2*x)/tan(sym('2'))+2*cos(2*x);
-%! assert (isequal (rhs(f), g))
+%! assert (isequal (simplify (f - g), 0))
 
 %!test
 %! % Neumann boundary conditions (second order ode)
@@ -256,7 +282,7 @@ end
 %! de = diff(y, 2) + 4*y == 0;
 %! f = dsolve(de, subs(diff(y,x),x,0)==1, subs(diff(y,x),x,1)==0);
 %! g = sin(2*x)/2+cos(2*x)/(2*tan(sym('2')));
-%! assert (isequal (rhs(f), g))
+%! assert (isequal (simplify (f - g), 0))
 
 %!test
 %! % Dirichlet-Neumann boundary conditions (second order ode)
@@ -264,7 +290,17 @@ end
 %! de = diff(y, 2) + 4*y == 0;
 %! f = dsolve(de, y(0) == 3, subs(diff(y,x),x,1)==0);
 %! g = 3*sin(2*x)*tan(sym('2'))+3*cos(2*x);
-%! assert (isequal (rhs(f), g))
+%! assert (isequal (simplify (f - g), 0))
+
+%!test
+%! % System of ODEs gives struct, Issue #1003.
+%! syms x(t) y(t)
+%! ode1 = diff(x(t),t) == 2*y(t);
+%! ode2 = diff(y(t),t) == 2*x(t);
+%! soln = dsolve([ode1, ode2]);
+%! assert (isstruct (soln))
+%! assert (numfields (soln) == 2)
+%! assert (isequal (sort (fieldnames (soln)), {'x'; 'y'}))
 
 %!test
 %! % System of ODEs
@@ -272,10 +308,17 @@ end
 %! ode1 = diff(x(t),t) == 2*y(t);
 %! ode2 = diff(y(t),t) == 2*x(t);
 %! soln = dsolve([ode1, ode2]);
-%! g1 = [2*C1*exp(-2*t) + 2*C2*exp(2*t), -2*C1*exp(-2*t) + 2*C2*exp(2*t)];
-%! g2 = [2*C1*exp(2*t) + 2*C2*exp(-2*t), 2*C1*exp(2*t) - 2*C2*exp(-2*t)];
-%! assert (isequal ([rhs(soln{1}), rhs(soln{2})], g1) || ...
-%!         isequal ([rhs(soln{1}), rhs(soln{2})], g2))
+%! soln = [soln.x, soln.y];
+%! g1 = [C1*exp(-2*t) + C2*exp(2*t), -C1*exp(-2*t) + C2*exp(2*t)];
+%! g2 = [C1*exp(2*t) + C2*exp(-2*t), C1*exp(2*t) - C2*exp(-2*t)];
+%! g3 = [-C1*exp(-2*t) + C2*exp(2*t), C1*exp(-2*t) + C2*exp(2*t)];
+%! g4 = [C1*exp(2*t) - C2*exp(-2*t), C1*exp(2*t) + C2*exp(-2*t)];
+%! % old SymPy <= 1.5.1 had some extra twos
+%! g5 = [2*C1*exp(-2*t) + 2*C2*exp(2*t), -2*C1*exp(-2*t) + 2*C2*exp(2*t)];
+%! g6 = [2*C1*exp(2*t) + 2*C2*exp(-2*t), 2*C1*exp(2*t) - 2*C2*exp(-2*t)];
+%! assert (isequal (soln, g1) || isequal (soln, g2) || ...
+%!         isequal (soln, g3) || isequal (soln, g4) || ...
+%!         isequal (soln, g5) || isequal (soln, g6))
 
 %!test
 %! % System of ODEs (initial-value problem)
@@ -284,14 +327,14 @@ end
 %! ode_2=diff(y(t),t) == 2*x(t);
 %! sol_ivp=dsolve([ode_1,ode_2],x(0)==1,y(0)==0);
 %! g_ivp=[exp(-2*t)/2+exp(2*t)/2,-exp(-2*t)/2+exp(2*t)/2];
-%! assert (isequal ([rhs(sol_ivp{1}),rhs(sol_ivp{2})], g_ivp))
+%! assert (isequal ([sol_ivp.x, sol_ivp.y], g_ivp))
 
 %!test
 %! syms y(x)
 %! de = diff(y, 2) + 4*y == 0;
 %! f = dsolve(de, y(0) == 0, y(sym(pi)/4) == 1);
 %! g = sin(2*x);
-%! assert (isequal (rhs(f), g))
+%! assert (isequal (f, g))
 
 %!test
 %! % Nonlinear example
@@ -299,7 +342,7 @@ end
 %! e = diff(y, x) == y^2;
 %! g = -1 / (C1 + x);
 %! soln = dsolve(e);
-%! assert (isequal (rhs(soln), g))
+%! assert (isequal (soln, g))
 
 %!test
 %! % Nonlinear example with initial condition
@@ -307,21 +350,58 @@ end
 %! e = diff(y, x) == y^2;
 %! g = -1 / (x - 1);
 %! soln = dsolve(e, y(0) == 1);
-%! assert (isequal (rhs(soln), g))
+%! assert (isequal (soln, g))
 
-%!xtest
-%! % forcing, Issue #183
+%!test
+%! % forcing, Issue #183, broken in older sympy
+%! if (pycall_sympy__ ('return Version(spver) >= Version("1.7.1")'))
 %! syms x(t) y(t)
 %! ode1 = diff(x) == x + sin(t) + 2;
 %! ode2 = diff(y) == y - t - 3;
 %! soln = dsolve([ode1 ode2], x(0) == 1, y(0) == 2);
-%! X = rhs(soln{1});
-%! Y = rhs(soln{2});
+%! X = soln.x;
+%! Y = soln.y;
 %! assert (isequal (diff(X) - (X + sin(t) + 2), 0))
 %! assert (isequal (diff(Y) - (Y - t - 3), 0))
+%! end
 
 %!test
 %! syms f(x) a b
 %! de = diff(f, x) == 4*f;
 %! s = dsolve(de, f(a) == b);
-%! assert (isequal (subs(rhs(s), x, a), b))
+%! assert (isequal (subs(s, x, a), b))
+
+%!test
+%! % array of ICs
+%! syms x(t) y(t)
+%! ode_1 = diff (x(t), t) == 2*y(t);
+%! ode_2 = diff (y(t), t) == 2*x(t);
+%! sol = dsolve([ode_1, ode_2], [x(0)==1 y(0)==0]);
+%! g = [exp(-2*t)/2+exp(2*t)/2, -exp(-2*t)/2+exp(2*t)/2];
+%! assert (isequal ([sol.x, sol.y], g))
+
+%!test
+%! % cell-array of ICs or ODEs, but not both
+%! % Note: to support both we'd need a wrapper outside of @sym
+%! syms x(t) y(t)
+%! ode_1 = diff (x(t), t) == 2*y(t);
+%! ode_2 = diff (y(t), t) == 2*x(t);
+%! sol = dsolve([ode_1, ode_2], {x(0)==1 y(0)==0});
+%! g = [exp(-2*t)/2+exp(2*t)/2, -exp(-2*t)/2+exp(2*t)/2];
+%! assert (isequal ([sol.x, sol.y], g))
+%! sol = dsolve({ode_1, ode_2}, [x(0)==1 y(0)==0]);
+%! g = [exp(-2*t)/2+exp(2*t)/2, -exp(-2*t)/2+exp(2*t)/2];
+%! assert (isequal ([sol.x, sol.y], g))
+
+%!test
+%! % array of ICs, Issue #1040.
+%! if (pycall_sympy__ ('return Version(spver) >= Version("1.7.1")'))
+%! syms x(t) y(t) z(t)
+%! syms x_0 y_0 z_0
+%! diffEqns = [diff(x, t) == -x + 1, diff(y, t) == -y, diff(z, t) == -z];
+%! initCond = [x(0) == x_0, y(0) == y_0, z(0) == z_0];
+%! soln = dsolve (diffEqns, initCond);
+%! soln = [soln.x, soln.y, soln.z];
+%! exact_soln = [(x_0 - 1)*exp(-t) + 1  y_0*exp(-t)  z_0*exp(-t)];
+%! assert (isequal (soln, exact_soln))
+%! end
