@@ -1,4 +1,4 @@
-%% Copyright (C) 2014-2016 Colin B. Macdonald
+%% Copyright (C) 2014-2016, 2019, 2024 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -18,18 +18,20 @@
 
 %% -*- texinfo -*-
 %% @documentencoding UTF-8
-%% @defmethod expm (@var{A})
+%% @defmethod @@sym expm (@var{A})
 %% Symbolic matrix exponential.
 %%
 %% Example:
 %% @example
 %% @group
+%% @c doctest: +SKIP_UNLESS(pycall_sympy__ ('return Version(spver) > Version("1.8")'))
 %% A = [sym(4) 1; sym(0) 4]
 %%   @result{} A = (sym 2×2 matrix)
 %%       ⎡4  1⎤
 %%       ⎢    ⎥
 %%       ⎣0  4⎦
 %%
+%% @c doctest: +SKIP_UNLESS(pycall_sympy__ ('return Version(spver) > Version("1.8")'))
 %% expm(A)
 %%   @result{} (sym 2×2 matrix)
 %%       ⎡ 4   4⎤
@@ -54,34 +56,42 @@ function z = expm(x)
           '    x = sp.Matrix([[x]])'
           'return x.exp(),' };
 
-  z = python_cmd (cmd, x);
+  z = pycall_sympy__ (cmd, x);
 
 end
 
 
 %!test
 %! % scalar
+%! if (pycall_sympy__ ('return Version(spver) >= Version("1.9")'))
 %! syms x
 %! assert (isequal (expm(x), exp(x)))
+%! end
 
 %!test
 %! % diagonal
+%! if (pycall_sympy__ ('return Version(spver) >= Version("1.9")'))
 %! A = [sym(1) 0; 0 sym(3)];
 %! B = [exp(sym(1)) 0; 0 exp(sym(3))];
 %! assert (isequal (expm(A), B))
+%! end
 
 %!test
 %! % diagonal w/ x
+%! if (pycall_sympy__ ('return Version(spver) >= Version("1.9")'))
 %! syms x positive
 %! A = [sym(1) 0; 0 x+2];
 %! B = [exp(sym(1)) 0; 0 exp(x+2)];
 %! assert (isequal (expm(A), B))
+%! end
 
 %!test
 %! % non-diagonal
+%! if (pycall_sympy__ ('return Version(spver) >= Version("1.9")'))
 %! syms x positive
 %! A = [sym(1) 2; 0 x+2];
 %! B = expm(A);
 %! C = double(subs(B, x, 4));
 %! D = expm(double(subs(A, x, 4)));
 %! assert (max (max (abs (C - D))) <= 1e-11)
+%! end
