@@ -1,4 +1,4 @@
-%% Copyright (C) 2014, 2016 Colin B. Macdonald
+%% Copyright (C) 2014, 2016, 2019 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -76,8 +76,6 @@
 %%          @@sym/hessian}
 %% @end defmethod
 
-%% Author: Colin B. Macdonald
-%% Keywords: symbolic
 
 function g = gradient(f,x)
 
@@ -104,7 +102,7 @@ function g = gradient(f,x)
           'G = f.jacobian(x).T'
           'return G,' };
 
-  g = python_cmd (cmd, sym(f), x);
+  g = pycall_sympy__ (cmd, sym(f), x);
 
 end
 
