@@ -1,4 +1,4 @@
-%% Copyright (C) 2014-2016 Colin B. Macdonald
+%% Copyright (C) 2014-2016, 2019, 2022, 2025 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -22,7 +22,7 @@
 %% @defmethodx @@sym horner (@var{p}, @var{x})
 %% Convert a symbolic polynomial to Horner form.
 %%
-%% The Horner form minimizes the number of arthimetic operators to
+%% The Horner form minimizes the number of arithmetic operators to
 %% evaluate the polynomial.
 %%
 %% Example:
@@ -63,15 +63,15 @@ function y = horner(p, x)
   end
 
   if (isempty(x))
-    y = python_cmd ('return sp.horner(*_ins),', sym(p));
+    y = pycall_sympy__ ('return sp.horner(*_ins),', sym(p));
   else
-    y = python_cmd ('return sp.horner(*_ins),', sym(p), sym(x));
+    y = pycall_sympy__ ('return sp.horner(*_ins),', sym(p), sym(x));
   end
 
 end
 
 
-%!error <Invalid> horner (sym(1), 2, 3)
+%!error horner (sym(1), 2, 3)
 
 %!assert (isAlways (horner(sym(1)) == 1))
 
