@@ -58,9 +58,9 @@ function y = ones(varargin)
   end
 
   if (length (varargin) == 1 && ~isscalar (varargin{1}))
-    y = python_cmd ('return ones(*_ins[0])', varargin{1});
+    y = pycall_sympy__ ('return ones(*_ins[0])', varargin{1});
   else
-    y = python_cmd ('return ones(*_ins)', varargin{:});
+    y = pycall_sympy__ ('return ones(*_ins)', varargin{:});
   end
 
 end
