@@ -1,4 +1,4 @@
-%% Copyright (C) 2014, 2016 Colin B. Macdonald
+%% Copyright (C) 2014, 2016, 2019 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -56,7 +56,7 @@ function b = subsindex(x)
       'else:'
       '    return 0,' };
 
-  flag = python_cmd (cmd, x);
+  flag = pycall_sympy__ (cmd, x);
 
   assert(isnumeric(flag))
 
