@@ -1,4 +1,5 @@
-%% Copyright (C) 2014-2018 Colin B. Macdonald
+%% SPDX-License-Identifier: GPL-3.0-or-later
+%% Copyright (C) 2014-2019, 2022-2025 Colin B. Macdonald
 %% Copyright (C) 2016 Lagu
 %%
 %% This file is part of OctSymPy.
@@ -91,7 +92,7 @@
 %% @group
 %% sym(0.1)
 %%   @print{} warning: passing floating-point values to sym is
-%%   @print{}          dangerous, see "help sym"
+%%   @print{}          dangerous, see "help sym"...
 %%   @result{} ans = (sym) 1/10
 %% @end group
 %% @end example
@@ -117,7 +118,7 @@
 %% @group
 %% y = sym(pi/100)
 %%   @print{} warning: passing floating-point values to sym is
-%%   @print{}          dangerous, see "help sym"
+%%   @print{}          dangerous, see "help sym"...
 %%   @result{} y = (sym)
 %%        π
 %%       ───
@@ -356,13 +357,17 @@ function s = sym(x, varargin)
   end
 
   if (~isscalar (x) && isnumber)  % Handle octave numeric matrix
-    s = numeric_array_to_sym (x);
+    if ratwarn
+      s = numeric_array_to_sym (x);
+    else
+      s = numeric_array_to_sym (x, ratflag);
+    end
     return
 
   elseif (isa (x, 'double'))  % Handle double/complex
     iscmplx = ~isreal (x);
     if (iscmplx && isequal (x, 1i))
-      s = python_cmd ('return S.ImaginaryUnit');
+      s = pycall_sympy__ ('return S.ImaginaryUnit');
       return
     elseif (iscmplx)
       xx = {real(x); imag(x)};
@@ -390,14 +395,14 @@ function s = sym(x, varargin)
     return
 
   elseif (isinteger (x)) % Handle integer vealues
-    s = python_cmd ('return Integer(*_ins)', x);
+    s = pycall_sympy__ ('return Integer(*_ins)', x);
     return
 
   elseif (islogical (x)) % Handle logical values
     if (x)
-      s = python_cmd ('return S.true');
+      s = pycall_sympy__ ('return S.true');
     else
-      s = python_cmd ('return S.false');
+      s = pycall_sympy__ ('return S.false');
     end
     return
   end
@@ -426,7 +431,7 @@ function s = sym(x, varargin)
     y = detect_special_str (x);
     if (~ isempty (y))
       assert (isempty (asm), 'Only symbols can have assumptions.')
-      s = python_cmd (['return ' y]);
+      s = pycall_sympy__ (['return ' y]);
       return
     end
 
@@ -449,7 +454,7 @@ function s = sym(x, varargin)
               '    else:'
               '        raise ValueError("something unexpected in assumptions")'
               'return Symbol(x, **d)' };
-      s = python_cmd (cmd, x, asm{:});
+      s = pycall_sympy__ (cmd, x, asm{:});
 
       if (nargin == 2 && sclear)
         % ---------------------------------------------
@@ -481,12 +486,12 @@ function s = sym(x, varargin)
       % Usually want rational output here (i.e., if input was "1.2").
       % But if input has words and parentheses it might be raw Sympy code.
       if (isempty (regexp (x, '\w\(.*\)')))
-        s = python_cmd (['return S("' x '", rational=True)']);
+        s = pycall_sympy__ (['return S("' x '", rational=True)']);
         return
       end
 
       hint_symfun = false;
-      %% distinguish b/w sym('FF(w)') and sym('FF(Symbol(...))')
+      %% distinguish b/w sym('ff(w)') and sym('ff(6, Symbol("w"))')
       % regexp detects F(<words commas spaces>)
       T = regexp (x, '^(\w+)\(([\w,\s]*)\)$', 'tokens');
       if (length (T) == 1 && length (T{1}) == 2)
@@ -495,38 +500,45 @@ function s = sym(x, varargin)
         varnamestr = T{1}{2};
         varnames = strtrim (strsplit (varnamestr, ','));
 
-        %% Blacklist some strings for which srepr(x) == str(x)
+        %% Blocklist some strings for which srepr(x) == str(x)
         % Python code for this:
         % >>> ns = {}; exec('from sympy import *', ns)
         % ... for (k, v) in ns.items():
         % ...    if not callable(v) and k not in ['__builtins__', 'C']:
         % ...        if k == srepr(v):
         % ...            print(k)
-        var_blacklist = {'E' 'I' 'nan' 'oo' 'pi' 'zoo' 'Catalan' ...
+        var_blocklist = {'E' 'I' 'nan' 'oo' 'pi' 'zoo' 'Catalan' ...
                          'EulerGamma' 'GoldenRatio' 'true' 'false'};
 
-        %% special case: if all (x,y,z) are in the blacklist, we should *not*
+        %% special case: if all (x,y,z) are in the blocklist, we should *not*
         % force symfun, thus preserving the identity sympy(sym(x)) == x
-        if (all (cellfun (@(v) (any (strcmp (v, var_blacklist))), varnames)))
+        if (all (cellfun (@(v) (any (strcmp (v, var_blocklist))), varnames)))
           hint_symfun = false;
         end
 
-        %% Whitelist some function names to always make a Function
+        %% special case some function names to always make a Function
         % Currently this is unused, but could be used if we want
         % different behaviour for the "I" in "I(t)" vs "F(I, t)".
         % SMT 2014 compat: does *not* have I, E here
-        %function_whitelist = {'I', 'E', 'ff', 'FF'};
+        %function_allowlist = {'I', 'E', 'ff', 'FF'};
         %if (hint_symfun)
-        %  if (any (strcmp (name, function_whitelist)))
+        %  if (any (strcmp (name, function_allowlist)))
         %    x = ['Function("' name '")(' varnamestr ')'];
         %  end
         %end
       end
 
+      % This routine tries to use SymPy's `sympify`, with various special casing
+      % for ff = FallingFactorial, N and other special symbols.
+      %
+      % On SymPy >= 1.10.1, can use `myclash = {v: "" ...}`.  The current
+      % `v: Function(v)` seems to work on old and new SymPy.
+      % TODO: once we support >= 1.10.1, probably we can make FF, ff match
+      % this stuff already in _clash1 (that is, use empty string).
       cmd = {'x, hint_symfun = _ins'
              'if hint_symfun:'
              '    from sympy.abc import _clash1'
-             '    myclash = {v: Symbol(v) for v in ["ff", "FF"]}'
+             '    myclash = {v: Function(v) for v in ["ff", "FF"]}'
              '    myclash.update(_clash1)'
              '    #myclash.pop("I", None)'  % remove for SMT compat
              '    #myclash.pop("E", None)'
@@ -537,7 +549,7 @@ function s = sym(x, varargin)
              'except Exception as e:'
              '    lis = set()'
              '    if "(" in x or ")" in x:'
-             '        x2 = split("\(|\)| |,", x)'
+             '        x2 = lib_re_split(r"\(|\)| |,", x)'
              '        x2 = [p for p in x2 if p]'
              '        for i in x2:'
              '            try:'
@@ -549,7 +561,7 @@ function s = sym(x, varargin)
              '        return (str(e), 1, "\", \"".join(str(e) for e in lis))'
              '    return (str(e), 2, 0)' };
 
-      [err flag s] = python_cmd (cmd, x, hint_symfun);
+      [err flag s] = pycall_sympy__ (cmd, x, hint_symfun);
 
       switch (flag)
         case 1  % Bad call to python function
@@ -618,6 +630,7 @@ end
 %! assert (isequal (2*x, sym (1)))
 
 %!warning <dangerous> x = sym (1/2);
+%!warning id=OctSymPy:sym:rationalapprox x = sym (1/2);
 
 %!test
 %! % passing small rationals w/o quotes: despite the warning,
@@ -840,6 +853,18 @@ end
 %! x = sym(a, 'r');
 %! assert (isequal (x, sym(1)/10))
 
+%!test
+%! % sym(double) array with 'r': no warning
+%! a = [0.1 0.2];
+%! x = sym(a, 'r');
+%! assert (isequal (x, [sym(a(1), 'r') sym(a(2), 'r')]))
+
+%!test
+%! % sym(double) array with 'f': no warning
+%! a = [0.1 0.2];
+%! x = sym(a, 'f');
+%! assert (isequal (x, [sym(a(1), 'f') sym(a(2), 'f')]))
+
 %!test
 %! % sym(double, 'f')
 %! a = 0.1;
@@ -911,11 +936,12 @@ end
 
 %!assert (~ isequal (sym (exp(1)), sym (exp(1), 'f')))
 
-%!warning <dangerous> sym (1e16);
-%!warning <dangerous> sym (-1e16);
-%!warning <dangerous> sym (10.33);
-%!warning <dangerous> sym (-5.23);
-%!warning <dangerous> sym (sqrt (1.4142135623731));
+%!warning id=OctSymPy:sym:rationalapprox sym (1e16);
+%!warning id=OctSymPy:sym:rationalapprox sym (-1e16);
+%!warning id=OctSymPy:sym:rationalapprox sym (10.33);
+%!warning id=OctSymPy:sym:rationalapprox sym (-5.23);
+%!warning id=OctSymPy:sym:rationalapprox sym (sqrt (1.4142135623731));
+%!warning id=OctSymPy:sym:rationalapprox sym ([1.2 1.3]);
 
 %!error <is not supported>
 %! x = sym ('x', 'positive2');
@@ -969,7 +995,7 @@ end
 %! a = sym ('2.1');
 %! b = sym (21) / 10;
 %! %% https://github.com/sympy/sympy/issues/11703
-%! assert (python_cmd ('return _ins[0] == _ins[1] and hash(_ins[0]) == hash(_ins[1])', a, b))
+%! assert (pycall_sympy__ ('return _ins[0] == _ins[1] and hash(_ins[0]) == hash(_ins[1])', a, b))
 
 %!test
 %! % issue #706
@@ -1063,9 +1089,9 @@ end
 %! assert (strcmp (s1, s2))
 
 %!test
-%! % For SMT 2014 compatibilty, I and E would become ImaginaryUnit and Exp(1)
+%! % For SMT 2014 compatibility, I and E would become ImaginaryUnit and Exp(1)
 %! % but I'm not sure this is by design.  This test would need to change if
-%! % we want stricter SMT compatibilty.
+%! % we want stricter SMT compatibility.
 %! f = sym ('f(x, I, E)');
 %! s1 = sympy (f);
 %! s2 = 'Function(''f'')(Symbol(''x''), Symbol(''I''), Symbol(''E''))';
@@ -1084,3 +1110,26 @@ end
 %! s1 = sympy (f);
 %! s2 = 'Function(''FF'')(Symbol(''w''), pi)';
 %! assert (strcmp (s1, s2))
+
+%!test
+%! % not the identity, force symfun
+%! f = sym ('ff(x, y)');
+%! s1 = sympy (f);
+%! s2 = 'Function(''ff'')(Symbol(''x''), Symbol(''y''))';
+%! assert (strcmp (s1, s2))
+
+%!test
+%! % But this one should satisfy "sym(sympy(x) == x" identity
+%! % (OOTB, SymPy has ff -> FallingFactorial)
+%! f = sym ('FallingFactorial(x, y)');
+%! s1 = sympy (f);
+%! s2 = 'FallingFactorial(Symbol(''x''), Symbol(''y''))';
+%! assert (strcmp (s1, s2))
+
+%!error <use another variable>
+%! % certain words cannot be used as variables
+%! if (pycall_sympy__ ('return Version(spver) >= Version("1.10.1")'))
+%!   f = sym ('f(x, y, print)')
+%! else
+%!   error ('use another variable')
+%! end
