@@ -1,4 +1,4 @@
-%% Copyright (C) 2014 Colin B. Macdonald
+%% Copyright (C) 2014, 2019 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -24,18 +24,18 @@ function [vars,s1,s2] = helper_symfun_binops(f, g)
       error('arithmetric operators on symfuns must have same vars')
     end
     vars = f.vars;
-    s1 = f.sym;
-    s2 = g.sym;
+    s1 = formula (f);
+    s2 = formula (g);
   elseif (isa(f,'symfun'))
     %disp('debug: symfun <op> sym')
     vars = f.vars;
-    s1 = f.sym;
+    s1 = formula (f);
     s2 = g;
   elseif (isa(g, 'symfun'))
     %disp('debug: sym <op> symfun')
     vars = g.vars;
     s1 = f;
-    s2 = g.sym;
+    s2 = formula (g);
   else
     error('Tertium Non Datur')
   end
