@@ -1,4 +1,5 @@
-%% Copyright (C) 2014-2015 Colin B. Macdonald
+%% SPDX-License-Identifier: GPL-3.0-or-later
+%% Copyright (C) 2014-2017, 2023-2024 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -16,10 +17,10 @@
 %% License along with this software; see the file COPYING.
 %% If not, see <http://www.gnu.org/licenses/>.
 
-function L = python_copy_vars_to(in, te, varargin)
+function L = python_copy_vars_to(in, try_except, varargin)
 %private function
 
-  if (~te)
+  if (~try_except)
     %% no error checking
     L = do_list(0, in, varargin);
     L = { sprintf('%s = []', in) ...
@@ -32,7 +33,7 @@ function L = python_copy_vars_to(in, te, varargin)
           L{:} ...
           '    octoutput_drv("PYTHON: successful variable import")' ...
           'except:' ...
-          '    echo_exception_stdout("while copying vars to Python")' ...
+          '    echo_exception_stdout("while copying variables to Python")' ...
           '    raise'
         };
   end
@@ -48,14 +49,23 @@ function a = do_list(indent, in, varlist)
 
     if (isa(x,'sym'))
       c=c+1; a{c} = [sp '# sym'];
-      % need to be careful here: pickle might have escape codes
-      % .append(pickle.loads("""%s"""))', x.pickle)
-      % The extra printf around the pickle helps if it still has
+      % The extra printf around the srepr helps if it still has
       % escape codes (and seems harmless if it does not)
-      % Issue #107: x.pickle fails for matrices, use char() as workaround
-      c=c+1; a{c} = sprintf('%s%s.append(%s)', sp, in, sprintf(char(x)));
+      c=c+1; a{c} = sprintf ('%s%s.append(%s)', sp, in, sprintf (sympy (x)));
 
     elseif (ischar(x))
+      assert (strcmp (x, '') || isrow (x), ...
+	      'multirow char arrays cannot be converted to Python strings')
+      if (exist ('OCTAVE_VERSION', 'builtin'))
+        x = undo_string_escapes(x);
+      else
+        % roughly same as the above on Matlab?
+        x = strrep(x, '\', '\\');
+        x = strrep(x, '"', '\"');
+        for cc = {'\n' '\r' '\t' '\b' '\f'}
+          x = strrep(x, sprintf(cc{:}), cc{:});
+        end
+      end
       c=c+1; a{c} = [sp in '.append("' x '")'];
       % or do we want a printf() around the string?
       %c=c+1; a{c} = sprintf('%s%s.append("%s")', sp, in, x);
@@ -71,7 +81,7 @@ function a = do_list(indent, in, varlist)
       c=c+1; a{c} = sprintf('%s%s.append(%s)  # int type', ...
                             sp, in, num2str(x, '%ld'));
 
-    elseif (isfloat(x) && isscalar(x))
+    elseif (isfloat(x) && isscalar(x) && isreal(x))
       % Floating point input.  By default, all Octave numbers are
       % IEEE double: we pass these using the exact hex
       % representation.  We could detect and treat
@@ -85,6 +95,13 @@ function a = do_list(indent, in, varlist)
       c=c+1; a{c} = sprintf('%s%s.append(hex2d("%s"))  # double', ...
                             sp, in, num2hex(x));
 
+    elseif (isfloat(x) && isscalar(x))  % iscomplex(x)
+      if (isa(x, 'single'))
+        x = double(x);  % don't hate, would happen in Python anyway
+      end
+      c=c+1; a{c} = sprintf('%s%s.append(hex2d("%s")+hex2d("%s")*1j)  # complex', ...
+                            sp, in, num2hex(real(x)), num2hex(imag(x)));
+
     elseif (iscell(x))
       c=c+1; a{c} = [sp '# cell array: xfer to list'];
       inn = [in 'n'];
@@ -112,8 +129,8 @@ function a = do_list(indent, in, varlist)
       % What should we do with double arrays?  Perhaps map them to numpy
       % arrays is the most useful in general.  For now, we map them to a
       % list-of-lists.  This could change in the future.  See also:
-      % https://github.com/cbm755/octsympy/issues/134
-      % https://github.com/cbm755/octsympy/pull/336
+      % https://github.com/gnu-octave/symbolic/issues/134
+      % https://github.com/gnu-octave/symbolic/pull/336
       c=c+1; a{c} = sprintf('%s%s.append(%s)', sp, in, sprintf(octave_array_to_python(x)));
 
     else
